@@ -3,8 +3,6 @@ library(dplyr)
 library(geepack)
 library(survey)
 library(testthat)
-library(zeligverse)
 
-suppressWarnings(RNGversion("3.5.0"))
 set.seed(123)
 test_check("Zelig")
